<?php

namespace Snaju\Inception\Config;

use Snaju\Inception\InceptionCore;
// use Snaju\Inception\Exception\DuplicateConfigKeyException;

/**
 * Class Config
 * @package Snaju\Inception\Config
 * The Config a specified directory and creates a list of key/value pairs to
 * use for the application.
 */
class Config
{
    private static $directory = 'config';

    private static $config = array();

    public static function init($appRoot = __DIR__)
    {
        $baseDir = $appRoot . DIRECTORY_SEPARATOR . self::$directory;

        if (! is_dir($baseDir)) {
            return;
        }

        // Read files in the config directory, group by filename, save to config array
        $configFiles = scandir($baseDir);
        $regex = '/([A-Za-z]+)(\.php)/i';

        foreach ($configFiles as $file) {
            if (preg_match($regex, trim($file))) {
                $key = explode('.', $file);
                self::$config[$key[0]] = include $baseDir . DIRECTORY_SEPARATOR . $file;
            }
        }
    }

    /**
     * Returns a saved config value based on the 'filename.key' keyGroup.
     * @param string $keyGroup
     * @return mixed|null
     */
    public static function get(string $keyGroup)
    {
        $regex = '/^[A-Za-z].+\.[A-Za-z]+$/i'; // filename.key

        if (preg_match($regex, trim($keyGroup))) {
            $keys = explode('.', $keyGroup);

            if (array_key_exists($keys[0], self::$config)) {
                return self::$config[$keys[0]][$keys[1]];
            }
            else {
                return null;
            }
        }
    }

    /**
     * Alias of `all` method.
     * @return array
     */
    public static function getAll(): array
    {
        return self::all();
    }

    /**
     * Returns the entire saved config array.
     * @return array
     */
    public static function all(): array
    {
        return self::$config;
    }

    /**
     * Convenience method to check if a file exists.
     * @param string $fileName
     * @return bool
     */
    public static function fileExists(string $fileName): bool
    {
        return !! array_key_exists(
            str_replace('.php', '', $fileName),
            self::$config
        );
    }

}